@@ -1,22 +1,22 @@
 use serde::Deserialize;
 use std::collections::BTreeMap as Map;
 
-use crate::user::{UserMetadata, User};
+use crate::user::{User, UserMetadata};
 use crate::Body;
 
 #[derive(Deserialize, Debug)]
-pub struct AnnotationDescription {
+pub struct Referent {
     pub _type: String,
     pub annotator_id: u32,
     pub annotator_login: String,
     pub api_path: String,
     pub classification: String,
-    pub fragment:String,
+    pub fragment: String,
     pub id: u32,
     pub is_description: bool,
     pub path: String,
     pub range: Map<String, String>,
-    pub song_id: u32,
+    pub song_id: Option<u32>,
     pub url: String,
     pub annotations: Vec<Annotation>,
 }
@@ -36,11 +36,11 @@ pub struct Annotation {
     pub verified: bool,
     pub votes_total: Option<u32>,
     pub current_user_metadata: UserMetadata,
-    pub authors: Vec<AnnotationAuthor>
+    pub authors: Vec<AnnotationAuthor>,
 }
 
 #[derive(Deserialize, Debug)]
 pub struct AnnotationAuthor {
     pub attribution: f32,
     pub user: User,
-}
\ No newline at end of file
+}
