@@ -1,11 +1,11 @@
 use crate::song::Song;
 
-use serde::{Deserialize};
+use serde::Deserialize;
 
 #[derive(Deserialize, Debug)]
 pub struct Hit {
     pub index: String,
     #[serde(rename = "type")]
     pub hit_type: String,
-    pub result: Song
-}
\ No newline at end of file
+    pub result: Song,
+}
